@@ -6,7 +6,7 @@ from typing import TYPE_CHECKING, Any, Dict, Optional
 
 import attr
 
-from procrastinate import types, utils
+from procrastinate import types
 
 if TYPE_CHECKING:
     from procrastinate import store  # noqa
@@ -92,6 +92,9 @@ class Job:
         context["call_string"] = self.call_string
         return context
 
+    def evolve(self, **kwargs: Any) -> "Job":
+        return attr.evolve(self, **kwargs)
+
     @cached_property
     def call_string(self):
         kwargs_string = ", ".join(
@@ -100,7 +103,6 @@ class Job:
         return f"{self.task_name}[{self.id}]({kwargs_string})"
 
 
-@utils.add_sync_api
 class JobDeferrer:
     """
     The main purpose of ``JobDeferrer`` is to get a hold of the job_store and the job,
@@ -118,22 +120,34 @@ class JobDeferrer:
 
         return attr.evolve(self.job, task_kwargs=final_kwargs)
 
+    def _log_before_defer_job(self, job: Job) -> None:
+        logger.debug(
+            f"About to defer job {job.call_string}",
+            extra={"action": "about_to_defer_job", "job": job.log_context()},
+        )
+
+    def _log_after_defer_job(self, job: Job) -> None:
+
+        logger.info(
+            f"Deferred job {job.call_string}",
+            extra={"action": "job_defer", "job": job.log_context()},
+        )
+
     async def defer_async(self, **task_kwargs: types.JSONValue) -> int:
         """
         See `Task.defer` for details.
         """
-
+        # Make sure this code stays synchronized with .defer()
         job = self.make_new_job(**task_kwargs)
+        self._log_before_defer_job(job=job)
+        id = await self.job_store.defer_job_async(job=job)
+        self._log_after_defer_job(job=job.evolve(id=id))
+        return id
 
-        context = job.log_context()
-        logger.debug(
-            f"About to defer job {job.call_string}",
-            extra={"action": "about_to_defer_job", "job": context},
-        )
-        id = await self.job_store.defer_job(job=job)
-        context["id"] = id
-        logger.info(
-            f"Deferred job {job.call_string} with id: {id}",
-            extra={"action": "job_defer", "job": context},
-        )
+    def defer(self, **task_kwargs: types.JSONValue) -> int:
+        # Make sure this code stays synchronized with .defer_async()
+        job = self.make_new_job(**task_kwargs)
+        self._log_before_defer_job(job=job)
+        id = self.job_store.defer_job(job=job)
+        self._log_after_defer_job(job=job.evolve(id=id))
         return id
